@@ -52,10 +52,10 @@ def is_running_inside_virtualenv():
 def parse_args(commandline_or_args):
     return commandline_or_args if isinstance(commandline_or_args, list) else commandline_or_args.split()
 
-def execute_assert_success(args):
+def execute_assert_success(args, env=None):
     from infi import execute
     logger.info("Executing {}".format(' '.join(args)))
-    result = execute.execute(args)
+    result = execute.execute(args, env=env)
     if result.get_returncode() is not None and result.get_returncode() != 0:
         raise PrettyExecutionError(result)
 
@@ -90,7 +90,6 @@ def execute_with_python(commandline_or_args):
         execute_assert_success(executable + args)
 
 def execute_with_isolated_python(commandline_or_args):
-    import sys
     import os
     from ..assertions import is_windows
     args = parse_args(commandline_or_args)
@@ -100,29 +99,29 @@ def execute_with_isolated_python(commandline_or_args):
             [executable] = os.path.abspath(executable[0])
     execute_assert_success(executable + args)
 
-def execute_with_buildout(commandline_or_args):
-    from os import name, path
+def execute_with_buildout(commandline_or_args, env=None):
+    from os import name, path, environ
+    _env = environ.copy()
+    if env:
+        _env.update(env)
     args = parse_args(commandline_or_args)
     execute_assert_success([path.join('bin', 'buildout{}'.format('.exe' if name == 'nt' else ''))] + \
-                            BUILDOUT_PARAMETERS + args)
+                            BUILDOUT_PARAMETERS + args, env=_env)
 
 @contextmanager
 def buildout_parameters_context(parameters):
     try:
-        _ = [BUILDOUT_PARAMETERS.append(param) for param in parameters if param not in BUILDOUT_PARAMETERS]
+        [BUILDOUT_PARAMETERS.append(param) for param in parameters if param not in BUILDOUT_PARAMETERS]
         yield
     finally:
-        _ = [BUILDOUT_PARAMETERS.remove(param) for param in parameters if param in BUILDOUT_PARAMETERS]
+        [BUILDOUT_PARAMETERS.remove(param) for param in parameters if param in BUILDOUT_PARAMETERS]
 
 def _release_version_with_git_flow(version_tag):
-    from os import curdir
     from gitflow.core import GitFlow
-    from gitpy import LocalRepository
     gitflow = GitFlow()
     gitflow.create("release", version_tag, base=None, fetch=False)
     gitflow.finish("release", version_tag, fetch=False, rebase=False, keep=False, force_delete=True,
                    tagging_info=dict(sign=False, message=version_tag))
-    repository = LocalRepository(curdir)
 
 def git_checkout(branch_name_or_tag):
     from os import curdir
@@ -130,7 +129,7 @@ def git_checkout(branch_name_or_tag):
     logger.info("checking out '{}'".format(branch_name_or_tag))
     try:
         LocalRepository(curdir).checkout(branch_name_or_tag)
-    except Exception: # pragma: no cover
+    except Exception:  # pragma: no cover
         logger.error("failed to checkout {}".format(branch_name_or_tag))
         raise SystemExit(1)
 
@@ -181,21 +180,19 @@ def set_freezed_versions_in_install_requires(buildout_cfg, versions_cfg):
     install_requires = to_dict(InstallRequiresPackageSet.from_value(buildout_cfg.get("project", "install_requires")))
     versions = to_dict(set([item.replace('==', ">=") for item in VersionSectionSet.from_value(versions_cfg)]))
     for key, value in versions.items():
-        if not install_requires.has_key(key):
+        if key not in install_requires:
             continue
-        if not install_requires[key]: # empty list
+        if not install_requires[key]:  # empty list
             install_requires[key] = value
     install_requires = from_dict(install_requires)
     buildout_cfg.set("project", "install_requires", InstallRequiresPackageSet.to_value(install_requires))
 
 def freeze_versions(versions_file, change_install_requires):
-    from os import curdir, path
     with open_buildout_configfile(write_on_exit=True) as buildout_cfg:
         with open_buildout_configfile(versions_file) as versions_cfg:
-            if not buildout_cfg.has_section("versions"):
-                buildout_cfg.add_section("versions")
-            for option in buildout_cfg.options("versions"):
-                buildout_cfg.remove_option("versions", option)
+            if buildout_cfg.has_section("versions"):
+                buildout_cfg.remove_section("versions")
+            buildout_cfg.add_section("versions")
             for option in sorted(versions_cfg.options("versions"), key=lambda s: s.lower()):
                 buildout_cfg.set("versions", option, versions_cfg.get("versions", option))
         if change_install_requires:
@@ -205,7 +202,7 @@ def unset_freezed_versions_in_install_requires(buildout_cfg):
     from .package_sets import InstallRequiresPackageSet, to_dict, from_dict
     install_requires = InstallRequiresPackageSet.from_value(buildout_cfg.get("project", "install_requires"))
     install_requires_dict = to_dict(install_requires)
-    install_requires_dict.update({key:[] for key, specs in install_requires_dict.items()
+    install_requires_dict.update({key: [] for key, specs in install_requires_dict.items()
                                   if specs and specs[-1][0] == '>='})
     install_requires = from_dict(install_requires_dict)
     buildout_cfg.set("project", "install_requires", InstallRequiresPackageSet.to_value(install_requires))
@@ -226,10 +223,10 @@ class RevertIfFailedOperations(object):
         self.repository = repository
 
     def get_tags(self):
-        return {tag.name:tag for tag in self.repository.getTags()}
+        return {tag.name: tag for tag in self.repository.getTags()}
 
     def get_branches(self):
-        return {branch.name:branch for branch in self.repository.getBranches()}
+        return {branch.name: branch for branch in self.repository.getBranches()}
 
     def get_head(self, branch_name):
         return self.repository.getBranchByName(branch_name).getHead()
